# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['QuotaPlanArgs', 'QuotaPlan']

@pulumi.input_type
class QuotaPlanArgs:
    def __init__(__self__, *,
                 nickname: pulumi.Input[builtins.str],
                 plan_name: pulumi.Input[builtins.str],
                 is_effective: Optional[pulumi.Input[builtins.bool]] = None,
                 quota: Optional[pulumi.Input['QuotaPlanQuotaArgs']] = None):
        """
        The set of arguments for constructing a QuotaPlan resource.
        :param pulumi.Input[builtins.str] nickname: Quota Name
        :param pulumi.Input[builtins.str] plan_name: The Quota plan name. Start with a letter, containing letters, numbers, and underscores (_). It is no more than 64 characters long.
        :param pulumi.Input[builtins.bool] is_effective: Whether to take effect immediately. “Valid values: true”  
               .> **NOTE:** when other quota plans in the same quota group take effect, the effective quota group will become invalid. That is, IsEffective will become false. The effective quota plan cannot be deleted.
        :param pulumi.Input['QuotaPlanQuotaArgs'] quota: Quota property See `quota` below.
        """
        pulumi.set(__self__, "nickname", nickname)
        pulumi.set(__self__, "plan_name", plan_name)
        if is_effective is not None:
            pulumi.set(__self__, "is_effective", is_effective)
        if quota is not None:
            pulumi.set(__self__, "quota", quota)

    @property
    @pulumi.getter
    def nickname(self) -> pulumi.Input[builtins.str]:
        """
        Quota Name
        """
        return pulumi.get(self, "nickname")

    @nickname.setter
    def nickname(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "nickname", value)

    @property
    @pulumi.getter(name="planName")
    def plan_name(self) -> pulumi.Input[builtins.str]:
        """
        The Quota plan name. Start with a letter, containing letters, numbers, and underscores (_). It is no more than 64 characters long.
        """
        return pulumi.get(self, "plan_name")

    @plan_name.setter
    def plan_name(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "plan_name", value)

    @property
    @pulumi.getter(name="isEffective")
    def is_effective(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Whether to take effect immediately. “Valid values: true”  
        .> **NOTE:** when other quota plans in the same quota group take effect, the effective quota group will become invalid. That is, IsEffective will become false. The effective quota plan cannot be deleted.
        """
        return pulumi.get(self, "is_effective")

    @is_effective.setter
    def is_effective(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "is_effective", value)

    @property
    @pulumi.getter
    def quota(self) -> Optional[pulumi.Input['QuotaPlanQuotaArgs']]:
        """
        Quota property See `quota` below.
        """
        return pulumi.get(self, "quota")

    @quota.setter
    def quota(self, value: Optional[pulumi.Input['QuotaPlanQuotaArgs']]):
        pulumi.set(self, "quota", value)


@pulumi.input_type
class _QuotaPlanState:
    def __init__(__self__, *,
                 is_effective: Optional[pulumi.Input[builtins.bool]] = None,
                 nickname: Optional[pulumi.Input[builtins.str]] = None,
                 plan_name: Optional[pulumi.Input[builtins.str]] = None,
                 quota: Optional[pulumi.Input['QuotaPlanQuotaArgs']] = None):
        """
        Input properties used for looking up and filtering QuotaPlan resources.
        :param pulumi.Input[builtins.bool] is_effective: Whether to take effect immediately. “Valid values: true”  
               .> **NOTE:** when other quota plans in the same quota group take effect, the effective quota group will become invalid. That is, IsEffective will become false. The effective quota plan cannot be deleted.
        :param pulumi.Input[builtins.str] nickname: Quota Name
        :param pulumi.Input[builtins.str] plan_name: The Quota plan name. Start with a letter, containing letters, numbers, and underscores (_). It is no more than 64 characters long.
        :param pulumi.Input['QuotaPlanQuotaArgs'] quota: Quota property See `quota` below.
        """
        if is_effective is not None:
            pulumi.set(__self__, "is_effective", is_effective)
        if nickname is not None:
            pulumi.set(__self__, "nickname", nickname)
        if plan_name is not None:
            pulumi.set(__self__, "plan_name", plan_name)
        if quota is not None:
            pulumi.set(__self__, "quota", quota)

    @property
    @pulumi.getter(name="isEffective")
    def is_effective(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Whether to take effect immediately. “Valid values: true”  
        .> **NOTE:** when other quota plans in the same quota group take effect, the effective quota group will become invalid. That is, IsEffective will become false. The effective quota plan cannot be deleted.
        """
        return pulumi.get(self, "is_effective")

    @is_effective.setter
    def is_effective(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "is_effective", value)

    @property
    @pulumi.getter
    def nickname(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Quota Name
        """
        return pulumi.get(self, "nickname")

    @nickname.setter
    def nickname(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "nickname", value)

    @property
    @pulumi.getter(name="planName")
    def plan_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The Quota plan name. Start with a letter, containing letters, numbers, and underscores (_). It is no more than 64 characters long.
        """
        return pulumi.get(self, "plan_name")

    @plan_name.setter
    def plan_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "plan_name", value)

    @property
    @pulumi.getter
    def quota(self) -> Optional[pulumi.Input['QuotaPlanQuotaArgs']]:
        """
        Quota property See `quota` below.
        """
        return pulumi.get(self, "quota")

    @quota.setter
    def quota(self, value: Optional[pulumi.Input['QuotaPlanQuotaArgs']]):
        pulumi.set(self, "quota", value)


@pulumi.type_token("alicloud:maxcompute/quotaPlan:QuotaPlan")
class QuotaPlan(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 is_effective: Optional[pulumi.Input[builtins.bool]] = None,
                 nickname: Optional[pulumi.Input[builtins.str]] = None,
                 plan_name: Optional[pulumi.Input[builtins.str]] = None,
                 quota: Optional[pulumi.Input[Union['QuotaPlanQuotaArgs', 'QuotaPlanQuotaArgsDict']]] = None,
                 __props__=None):
        """
        Provides a Max Compute Quota Plan resource.

        For information about Max Compute Quota Plan and how to use it, see [What is Quota Plan](https://www.alibabacloud.com/help/en/).

        > **NOTE:** Available since v1.242.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        elastic_reserved_cu = config.get("elasticReservedCu")
        if elastic_reserved_cu is None:
            elastic_reserved_cu = "50"
        default = alicloud.maxcompute.QuotaPlan("default",
            nickname="os_terrform_p",
            quota={
                "parameter": {
                    "elastic_reserved_cu": elastic_reserved_cu,
                },
                "sub_quota_info_lists": [
                    {
                        "nick_name": "sub_quota",
                        "parameter": {
                            "min_cu": 0,
                            "max_cu": 20,
                            "elastic_reserved_cu": elastic_reserved_cu,
                        },
                    },
                    {
                        "nick_name": "os_terrform",
                        "parameter": {
                            "min_cu": 50,
                            "max_cu": 50,
                            "elastic_reserved_cu": 0,
                        },
                    },
                ],
            },
            plan_name="quota_plan")
        ```

        ## Import

        Max Compute Quota Plan can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:maxcompute/quotaPlan:QuotaPlan example <nickname>:<plan_name>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.bool] is_effective: Whether to take effect immediately. “Valid values: true”  
               .> **NOTE:** when other quota plans in the same quota group take effect, the effective quota group will become invalid. That is, IsEffective will become false. The effective quota plan cannot be deleted.
        :param pulumi.Input[builtins.str] nickname: Quota Name
        :param pulumi.Input[builtins.str] plan_name: The Quota plan name. Start with a letter, containing letters, numbers, and underscores (_). It is no more than 64 characters long.
        :param pulumi.Input[Union['QuotaPlanQuotaArgs', 'QuotaPlanQuotaArgsDict']] quota: Quota property See `quota` below.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: QuotaPlanArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a Max Compute Quota Plan resource.

        For information about Max Compute Quota Plan and how to use it, see [What is Quota Plan](https://www.alibabacloud.com/help/en/).

        > **NOTE:** Available since v1.242.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        elastic_reserved_cu = config.get("elasticReservedCu")
        if elastic_reserved_cu is None:
            elastic_reserved_cu = "50"
        default = alicloud.maxcompute.QuotaPlan("default",
            nickname="os_terrform_p",
            quota={
                "parameter": {
                    "elastic_reserved_cu": elastic_reserved_cu,
                },
                "sub_quota_info_lists": [
                    {
                        "nick_name": "sub_quota",
                        "parameter": {
                            "min_cu": 0,
                            "max_cu": 20,
                            "elastic_reserved_cu": elastic_reserved_cu,
                        },
                    },
                    {
                        "nick_name": "os_terrform",
                        "parameter": {
                            "min_cu": 50,
                            "max_cu": 50,
                            "elastic_reserved_cu": 0,
                        },
                    },
                ],
            },
            plan_name="quota_plan")
        ```

        ## Import

        Max Compute Quota Plan can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:maxcompute/quotaPlan:QuotaPlan example <nickname>:<plan_name>
        ```

        :param str resource_name: The name of the resource.
        :param QuotaPlanArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(QuotaPlanArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 is_effective: Optional[pulumi.Input[builtins.bool]] = None,
                 nickname: Optional[pulumi.Input[builtins.str]] = None,
                 plan_name: Optional[pulumi.Input[builtins.str]] = None,
                 quota: Optional[pulumi.Input[Union['QuotaPlanQuotaArgs', 'QuotaPlanQuotaArgsDict']]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = QuotaPlanArgs.__new__(QuotaPlanArgs)

            __props__.__dict__["is_effective"] = is_effective
            if nickname is None and not opts.urn:
                raise TypeError("Missing required property 'nickname'")
            __props__.__dict__["nickname"] = nickname
            if plan_name is None and not opts.urn:
                raise TypeError("Missing required property 'plan_name'")
            __props__.__dict__["plan_name"] = plan_name
            __props__.__dict__["quota"] = quota
        super(QuotaPlan, __self__).__init__(
            'alicloud:maxcompute/quotaPlan:QuotaPlan',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            is_effective: Optional[pulumi.Input[builtins.bool]] = None,
            nickname: Optional[pulumi.Input[builtins.str]] = None,
            plan_name: Optional[pulumi.Input[builtins.str]] = None,
            quota: Optional[pulumi.Input[Union['QuotaPlanQuotaArgs', 'QuotaPlanQuotaArgsDict']]] = None) -> 'QuotaPlan':
        """
        Get an existing QuotaPlan resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.bool] is_effective: Whether to take effect immediately. “Valid values: true”  
               .> **NOTE:** when other quota plans in the same quota group take effect, the effective quota group will become invalid. That is, IsEffective will become false. The effective quota plan cannot be deleted.
        :param pulumi.Input[builtins.str] nickname: Quota Name
        :param pulumi.Input[builtins.str] plan_name: The Quota plan name. Start with a letter, containing letters, numbers, and underscores (_). It is no more than 64 characters long.
        :param pulumi.Input[Union['QuotaPlanQuotaArgs', 'QuotaPlanQuotaArgsDict']] quota: Quota property See `quota` below.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _QuotaPlanState.__new__(_QuotaPlanState)

        __props__.__dict__["is_effective"] = is_effective
        __props__.__dict__["nickname"] = nickname
        __props__.__dict__["plan_name"] = plan_name
        __props__.__dict__["quota"] = quota
        return QuotaPlan(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="isEffective")
    def is_effective(self) -> pulumi.Output[Optional[builtins.bool]]:
        """
        Whether to take effect immediately. “Valid values: true”  
        .> **NOTE:** when other quota plans in the same quota group take effect, the effective quota group will become invalid. That is, IsEffective will become false. The effective quota plan cannot be deleted.
        """
        return pulumi.get(self, "is_effective")

    @property
    @pulumi.getter
    def nickname(self) -> pulumi.Output[builtins.str]:
        """
        Quota Name
        """
        return pulumi.get(self, "nickname")

    @property
    @pulumi.getter(name="planName")
    def plan_name(self) -> pulumi.Output[builtins.str]:
        """
        The Quota plan name. Start with a letter, containing letters, numbers, and underscores (_). It is no more than 64 characters long.
        """
        return pulumi.get(self, "plan_name")

    @property
    @pulumi.getter
    def quota(self) -> pulumi.Output[Optional['outputs.QuotaPlanQuota']]:
        """
        Quota property See `quota` below.
        """
        return pulumi.get(self, "quota")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetApplicationGroupsResult',
    'AwaitableGetApplicationGroupsResult',
    'get_application_groups',
    'get_application_groups_output',
]

@pulumi.output_type
class GetApplicationGroupsResult:
    """
    A collection of values returned by getApplicationGroups.
    """
    def __init__(__self__, application_name=None, deploy_region_id=None, groups=None, id=None, ids=None, name_regex=None, names=None, output_file=None):
        if application_name and not isinstance(application_name, str):
            raise TypeError("Expected argument 'application_name' to be a str")
        pulumi.set(__self__, "application_name", application_name)
        if deploy_region_id and not isinstance(deploy_region_id, str):
            raise TypeError("Expected argument 'deploy_region_id' to be a str")
        pulumi.set(__self__, "deploy_region_id", deploy_region_id)
        if groups and not isinstance(groups, list):
            raise TypeError("Expected argument 'groups' to be a list")
        pulumi.set(__self__, "groups", groups)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ids and not isinstance(ids, list):
            raise TypeError("Expected argument 'ids' to be a list")
        pulumi.set(__self__, "ids", ids)
        if name_regex and not isinstance(name_regex, str):
            raise TypeError("Expected argument 'name_regex' to be a str")
        pulumi.set(__self__, "name_regex", name_regex)
        if names and not isinstance(names, list):
            raise TypeError("Expected argument 'names' to be a list")
        pulumi.set(__self__, "names", names)
        if output_file and not isinstance(output_file, str):
            raise TypeError("Expected argument 'output_file' to be a str")
        pulumi.set(__self__, "output_file", output_file)

    @property
    @pulumi.getter(name="applicationName")
    def application_name(self) -> builtins.str:
        return pulumi.get(self, "application_name")

    @property
    @pulumi.getter(name="deployRegionId")
    def deploy_region_id(self) -> Optional[builtins.str]:
        return pulumi.get(self, "deploy_region_id")

    @property
    @pulumi.getter
    def groups(self) -> Sequence['outputs.GetApplicationGroupsGroupResult']:
        return pulumi.get(self, "groups")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def ids(self) -> Sequence[builtins.str]:
        return pulumi.get(self, "ids")

    @property
    @pulumi.getter(name="nameRegex")
    def name_regex(self) -> Optional[builtins.str]:
        return pulumi.get(self, "name_regex")

    @property
    @pulumi.getter
    def names(self) -> Sequence[builtins.str]:
        return pulumi.get(self, "names")

    @property
    @pulumi.getter(name="outputFile")
    def output_file(self) -> Optional[builtins.str]:
        return pulumi.get(self, "output_file")


class AwaitableGetApplicationGroupsResult(GetApplicationGroupsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetApplicationGroupsResult(
            application_name=self.application_name,
            deploy_region_id=self.deploy_region_id,
            groups=self.groups,
            id=self.id,
            ids=self.ids,
            name_regex=self.name_regex,
            names=self.names,
            output_file=self.output_file)


def get_application_groups(application_name: Optional[builtins.str] = None,
                           deploy_region_id: Optional[builtins.str] = None,
                           ids: Optional[Sequence[builtins.str]] = None,
                           name_regex: Optional[builtins.str] = None,
                           output_file: Optional[builtins.str] = None,
                           opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetApplicationGroupsResult:
    """
    This data source provides the Oos Application Groups of the current Alibaba Cloud user.

    > **NOTE:** Available in v1.146.0+.

    ## Example Usage

    Basic Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    ids = alicloud.oos.get_application_groups(application_name="example_value",
        ids=[
            "my-ApplicationGroup-1",
            "my-ApplicationGroup-2",
        ])
    pulumi.export("oosApplicationGroupId1", ids.groups[0].id)
    name_regex = alicloud.oos.get_application_groups(application_name="example_value",
        name_regex="^my-ApplicationGroup")
    pulumi.export("oosApplicationGroupId2", name_regex.groups[0].id)
    ```


    :param builtins.str application_name: The name of the Application.
    :param builtins.str deploy_region_id: The region ID of the deployment.
    :param Sequence[builtins.str] ids: A list of Application Group IDs. Its element value is same as Application Group Name.
    :param builtins.str name_regex: A regex string to filter results by Application Group name.
    :param builtins.str output_file: File name where to save data source results (after running `pulumi preview`).
    """
    __args__ = dict()
    __args__['applicationName'] = application_name
    __args__['deployRegionId'] = deploy_region_id
    __args__['ids'] = ids
    __args__['nameRegex'] = name_regex
    __args__['outputFile'] = output_file
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('alicloud:oos/getApplicationGroups:getApplicationGroups', __args__, opts=opts, typ=GetApplicationGroupsResult).value

    return AwaitableGetApplicationGroupsResult(
        application_name=pulumi.get(__ret__, 'application_name'),
        deploy_region_id=pulumi.get(__ret__, 'deploy_region_id'),
        groups=pulumi.get(__ret__, 'groups'),
        id=pulumi.get(__ret__, 'id'),
        ids=pulumi.get(__ret__, 'ids'),
        name_regex=pulumi.get(__ret__, 'name_regex'),
        names=pulumi.get(__ret__, 'names'),
        output_file=pulumi.get(__ret__, 'output_file'))
def get_application_groups_output(application_name: Optional[pulumi.Input[builtins.str]] = None,
                                  deploy_region_id: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                                  ids: Optional[pulumi.Input[Optional[Sequence[builtins.str]]]] = None,
                                  name_regex: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                                  output_file: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                                  opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetApplicationGroupsResult]:
    """
    This data source provides the Oos Application Groups of the current Alibaba Cloud user.

    > **NOTE:** Available in v1.146.0+.

    ## Example Usage

    Basic Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    ids = alicloud.oos.get_application_groups(application_name="example_value",
        ids=[
            "my-ApplicationGroup-1",
            "my-ApplicationGroup-2",
        ])
    pulumi.export("oosApplicationGroupId1", ids.groups[0].id)
    name_regex = alicloud.oos.get_application_groups(application_name="example_value",
        name_regex="^my-ApplicationGroup")
    pulumi.export("oosApplicationGroupId2", name_regex.groups[0].id)
    ```


    :param builtins.str application_name: The name of the Application.
    :param builtins.str deploy_region_id: The region ID of the deployment.
    :param Sequence[builtins.str] ids: A list of Application Group IDs. Its element value is same as Application Group Name.
    :param builtins.str name_regex: A regex string to filter results by Application Group name.
    :param builtins.str output_file: File name where to save data source results (after running `pulumi preview`).
    """
    __args__ = dict()
    __args__['applicationName'] = application_name
    __args__['deployRegionId'] = deploy_region_id
    __args__['ids'] = ids
    __args__['nameRegex'] = name_regex
    __args__['outputFile'] = output_file
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('alicloud:oos/getApplicationGroups:getApplicationGroups', __args__, opts=opts, typ=GetApplicationGroupsResult)
    return __ret__.apply(lambda __response__: GetApplicationGroupsResult(
        application_name=pulumi.get(__response__, 'application_name'),
        deploy_region_id=pulumi.get(__response__, 'deploy_region_id'),
        groups=pulumi.get(__response__, 'groups'),
        id=pulumi.get(__response__, 'id'),
        ids=pulumi.get(__response__, 'ids'),
        name_regex=pulumi.get(__response__, 'name_regex'),
        names=pulumi.get(__response__, 'names'),
        output_file=pulumi.get(__response__, 'output_file')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['UserGroupAttachmentArgs', 'UserGroupAttachment']

@pulumi.input_type
class UserGroupAttachmentArgs:
    def __init__(__self__, *,
                 group_name: pulumi.Input[builtins.str],
                 user_name: pulumi.Input[builtins.str]):
        """
        The set of arguments for constructing a UserGroupAttachment resource.
        :param pulumi.Input[builtins.str] group_name: The name of group.
        :param pulumi.Input[builtins.str] user_name: The name of user.
        """
        pulumi.set(__self__, "group_name", group_name)
        pulumi.set(__self__, "user_name", user_name)

    @property
    @pulumi.getter(name="groupName")
    def group_name(self) -> pulumi.Input[builtins.str]:
        """
        The name of group.
        """
        return pulumi.get(self, "group_name")

    @group_name.setter
    def group_name(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "group_name", value)

    @property
    @pulumi.getter(name="userName")
    def user_name(self) -> pulumi.Input[builtins.str]:
        """
        The name of user.
        """
        return pulumi.get(self, "user_name")

    @user_name.setter
    def user_name(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "user_name", value)


@pulumi.input_type
class _UserGroupAttachmentState:
    def __init__(__self__, *,
                 group_name: Optional[pulumi.Input[builtins.str]] = None,
                 user_name: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering UserGroupAttachment resources.
        :param pulumi.Input[builtins.str] group_name: The name of group.
        :param pulumi.Input[builtins.str] user_name: The name of user.
        """
        if group_name is not None:
            pulumi.set(__self__, "group_name", group_name)
        if user_name is not None:
            pulumi.set(__self__, "user_name", user_name)

    @property
    @pulumi.getter(name="groupName")
    def group_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The name of group.
        """
        return pulumi.get(self, "group_name")

    @group_name.setter
    def group_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "group_name", value)

    @property
    @pulumi.getter(name="userName")
    def user_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The name of user.
        """
        return pulumi.get(self, "user_name")

    @user_name.setter
    def user_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "user_name", value)


@pulumi.type_token("alicloud:ram/userGroupAttachment:UserGroupAttachment")
class UserGroupAttachment(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 group_name: Optional[pulumi.Input[builtins.str]] = None,
                 user_name: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        Provides a RAM User Group Attachment resource.

        For information about RAM User Group Attachment and how to use it, see [What is User Group Attachment](https://next.api.alibabacloud.com/document/Ram/2015-05-01/AddUserToGroup).

        > **NOTE:** Available since v1.245.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud
        import pulumi_random as random

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        default = random.index.Integer("default",
            min=10000,
            max=99999)
        default_user = alicloud.ram.User("default",
            name=f"terraform-example-{default['result']}",
            display_name=f"terraform-example-{default['result']}")
        default_group = alicloud.ram.Group("default", name=f"terraform-example-{default['result']}")
        default_user_group_attachment = alicloud.ram.UserGroupAttachment("default",
            group_name=default_group.id,
            user_name=default_user.name)
        ```

        ## Import

        RAM User Group Attachment can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:ram/userGroupAttachment:UserGroupAttachment example <group_name>:<user_name>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] group_name: The name of group.
        :param pulumi.Input[builtins.str] user_name: The name of user.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: UserGroupAttachmentArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a RAM User Group Attachment resource.

        For information about RAM User Group Attachment and how to use it, see [What is User Group Attachment](https://next.api.alibabacloud.com/document/Ram/2015-05-01/AddUserToGroup).

        > **NOTE:** Available since v1.245.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud
        import pulumi_random as random

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        default = random.index.Integer("default",
            min=10000,
            max=99999)
        default_user = alicloud.ram.User("default",
            name=f"terraform-example-{default['result']}",
            display_name=f"terraform-example-{default['result']}")
        default_group = alicloud.ram.Group("default", name=f"terraform-example-{default['result']}")
        default_user_group_attachment = alicloud.ram.UserGroupAttachment("default",
            group_name=default_group.id,
            user_name=default_user.name)
        ```

        ## Import

        RAM User Group Attachment can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:ram/userGroupAttachment:UserGroupAttachment example <group_name>:<user_name>
        ```

        :param str resource_name: The name of the resource.
        :param UserGroupAttachmentArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(UserGroupAttachmentArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 group_name: Optional[pulumi.Input[builtins.str]] = None,
                 user_name: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = UserGroupAttachmentArgs.__new__(UserGroupAttachmentArgs)

            if group_name is None and not opts.urn:
                raise TypeError("Missing required property 'group_name'")
            __props__.__dict__["group_name"] = group_name
            if user_name is None and not opts.urn:
                raise TypeError("Missing required property 'user_name'")
            __props__.__dict__["user_name"] = user_name
        super(UserGroupAttachment, __self__).__init__(
            'alicloud:ram/userGroupAttachment:UserGroupAttachment',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            group_name: Optional[pulumi.Input[builtins.str]] = None,
            user_name: Optional[pulumi.Input[builtins.str]] = None) -> 'UserGroupAttachment':
        """
        Get an existing UserGroupAttachment resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] group_name: The name of group.
        :param pulumi.Input[builtins.str] user_name: The name of user.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _UserGroupAttachmentState.__new__(_UserGroupAttachmentState)

        __props__.__dict__["group_name"] = group_name
        __props__.__dict__["user_name"] = user_name
        return UserGroupAttachment(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="groupName")
    def group_name(self) -> pulumi.Output[builtins.str]:
        """
        The name of group.
        """
        return pulumi.get(self, "group_name")

    @property
    @pulumi.getter(name="userName")
    def user_name(self) -> pulumi.Output[builtins.str]:
        """
        The name of user.
        """
        return pulumi.get(self, "user_name")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['ClientCertificateArgs', 'ClientCertificate']

@pulumi.input_type
class ClientCertificateArgs:
    def __init__(__self__, *,
                 site_id: pulumi.Input[builtins.int],
                 validity_days: pulumi.Input[builtins.str],
                 csr: Optional[pulumi.Input[builtins.str]] = None,
                 pkey_type: Optional[pulumi.Input[builtins.str]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None):
        """
        The set of arguments for constructing a ClientCertificate resource.
        :param pulumi.Input[builtins.int] site_id: Site Id
        :param pulumi.Input[builtins.str] validity_days: Certificate validity period.
        :param pulumi.Input[builtins.str] csr: Certificate signing request content.
        :param pulumi.Input[builtins.str] pkey_type: The private key algorithm type.
        :param pulumi.Input[builtins.str] status: The certificate status. Valid values: `revoked`, `active`.
        """
        pulumi.set(__self__, "site_id", site_id)
        pulumi.set(__self__, "validity_days", validity_days)
        if csr is not None:
            pulumi.set(__self__, "csr", csr)
        if pkey_type is not None:
            pulumi.set(__self__, "pkey_type", pkey_type)
        if status is not None:
            pulumi.set(__self__, "status", status)

    @property
    @pulumi.getter(name="siteId")
    def site_id(self) -> pulumi.Input[builtins.int]:
        """
        Site Id
        """
        return pulumi.get(self, "site_id")

    @site_id.setter
    def site_id(self, value: pulumi.Input[builtins.int]):
        pulumi.set(self, "site_id", value)

    @property
    @pulumi.getter(name="validityDays")
    def validity_days(self) -> pulumi.Input[builtins.str]:
        """
        Certificate validity period.
        """
        return pulumi.get(self, "validity_days")

    @validity_days.setter
    def validity_days(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "validity_days", value)

    @property
    @pulumi.getter
    def csr(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Certificate signing request content.
        """
        return pulumi.get(self, "csr")

    @csr.setter
    def csr(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "csr", value)

    @property
    @pulumi.getter(name="pkeyType")
    def pkey_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The private key algorithm type.
        """
        return pulumi.get(self, "pkey_type")

    @pkey_type.setter
    def pkey_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "pkey_type", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The certificate status. Valid values: `revoked`, `active`.
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "status", value)


@pulumi.input_type
class _ClientCertificateState:
    def __init__(__self__, *,
                 client_cert_id: Optional[pulumi.Input[builtins.str]] = None,
                 create_time: Optional[pulumi.Input[builtins.str]] = None,
                 csr: Optional[pulumi.Input[builtins.str]] = None,
                 pkey_type: Optional[pulumi.Input[builtins.str]] = None,
                 site_id: Optional[pulumi.Input[builtins.int]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None,
                 validity_days: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering ClientCertificate resources.
        :param pulumi.Input[builtins.str] client_cert_id: ClientCertificate Id
        :param pulumi.Input[builtins.str] create_time: The time when the certificate was created.
        :param pulumi.Input[builtins.str] csr: Certificate signing request content.
        :param pulumi.Input[builtins.str] pkey_type: The private key algorithm type.
        :param pulumi.Input[builtins.int] site_id: Site Id
        :param pulumi.Input[builtins.str] status: The certificate status. Valid values: `revoked`, `active`.
        :param pulumi.Input[builtins.str] validity_days: Certificate validity period.
        """
        if client_cert_id is not None:
            pulumi.set(__self__, "client_cert_id", client_cert_id)
        if create_time is not None:
            pulumi.set(__self__, "create_time", create_time)
        if csr is not None:
            pulumi.set(__self__, "csr", csr)
        if pkey_type is not None:
            pulumi.set(__self__, "pkey_type", pkey_type)
        if site_id is not None:
            pulumi.set(__self__, "site_id", site_id)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if validity_days is not None:
            pulumi.set(__self__, "validity_days", validity_days)

    @property
    @pulumi.getter(name="clientCertId")
    def client_cert_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        ClientCertificate Id
        """
        return pulumi.get(self, "client_cert_id")

    @client_cert_id.setter
    def client_cert_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "client_cert_id", value)

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The time when the certificate was created.
        """
        return pulumi.get(self, "create_time")

    @create_time.setter
    def create_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "create_time", value)

    @property
    @pulumi.getter
    def csr(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Certificate signing request content.
        """
        return pulumi.get(self, "csr")

    @csr.setter
    def csr(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "csr", value)

    @property
    @pulumi.getter(name="pkeyType")
    def pkey_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The private key algorithm type.
        """
        return pulumi.get(self, "pkey_type")

    @pkey_type.setter
    def pkey_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "pkey_type", value)

    @property
    @pulumi.getter(name="siteId")
    def site_id(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        Site Id
        """
        return pulumi.get(self, "site_id")

    @site_id.setter
    def site_id(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "site_id", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The certificate status. Valid values: `revoked`, `active`.
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter(name="validityDays")
    def validity_days(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Certificate validity period.
        """
        return pulumi.get(self, "validity_days")

    @validity_days.setter
    def validity_days(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "validity_days", value)


@pulumi.type_token("alicloud:esa/clientCertificate:ClientCertificate")
class ClientCertificate(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 csr: Optional[pulumi.Input[builtins.str]] = None,
                 pkey_type: Optional[pulumi.Input[builtins.str]] = None,
                 site_id: Optional[pulumi.Input[builtins.int]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None,
                 validity_days: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        Provides a ESA Client Certificate resource.

        For information about ESA Client Certificate and how to use it, see [What is Client Certificate](https://next.api.alibabacloud.com/document/ESA/2024-09-10/CreateClientCertificate).

        > **NOTE:** Available since v1.244.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        default = alicloud.esa.get_sites(plan_subscribe_type="enterpriseplan",
            site_name="gositecdn.cn")
        default_client_certificate = alicloud.esa.ClientCertificate("default",
            site_id=default.sites[0].id,
            pkey_type="RSA",
            validity_days="365")
        ```

        ## Import

        ESA Client Certificate can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:esa/clientCertificate:ClientCertificate example <site_id>:<client_cert_id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] csr: Certificate signing request content.
        :param pulumi.Input[builtins.str] pkey_type: The private key algorithm type.
        :param pulumi.Input[builtins.int] site_id: Site Id
        :param pulumi.Input[builtins.str] status: The certificate status. Valid values: `revoked`, `active`.
        :param pulumi.Input[builtins.str] validity_days: Certificate validity period.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ClientCertificateArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a ESA Client Certificate resource.

        For information about ESA Client Certificate and how to use it, see [What is Client Certificate](https://next.api.alibabacloud.com/document/ESA/2024-09-10/CreateClientCertificate).

        > **NOTE:** Available since v1.244.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        default = alicloud.esa.get_sites(plan_subscribe_type="enterpriseplan",
            site_name="gositecdn.cn")
        default_client_certificate = alicloud.esa.ClientCertificate("default",
            site_id=default.sites[0].id,
            pkey_type="RSA",
            validity_days="365")
        ```

        ## Import

        ESA Client Certificate can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:esa/clientCertificate:ClientCertificate example <site_id>:<client_cert_id>
        ```

        :param str resource_name: The name of the resource.
        :param ClientCertificateArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ClientCertificateArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 csr: Optional[pulumi.Input[builtins.str]] = None,
                 pkey_type: Optional[pulumi.Input[builtins.str]] = None,
                 site_id: Optional[pulumi.Input[builtins.int]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None,
                 validity_days: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ClientCertificateArgs.__new__(ClientCertificateArgs)

            __props__.__dict__["csr"] = csr
            __props__.__dict__["pkey_type"] = pkey_type
            if site_id is None and not opts.urn:
                raise TypeError("Missing required property 'site_id'")
            __props__.__dict__["site_id"] = site_id
            __props__.__dict__["status"] = status
            if validity_days is None and not opts.urn:
                raise TypeError("Missing required property 'validity_days'")
            __props__.__dict__["validity_days"] = validity_days
            __props__.__dict__["client_cert_id"] = None
            __props__.__dict__["create_time"] = None
        super(ClientCertificate, __self__).__init__(
            'alicloud:esa/clientCertificate:ClientCertificate',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            client_cert_id: Optional[pulumi.Input[builtins.str]] = None,
            create_time: Optional[pulumi.Input[builtins.str]] = None,
            csr: Optional[pulumi.Input[builtins.str]] = None,
            pkey_type: Optional[pulumi.Input[builtins.str]] = None,
            site_id: Optional[pulumi.Input[builtins.int]] = None,
            status: Optional[pulumi.Input[builtins.str]] = None,
            validity_days: Optional[pulumi.Input[builtins.str]] = None) -> 'ClientCertificate':
        """
        Get an existing ClientCertificate resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] client_cert_id: ClientCertificate Id
        :param pulumi.Input[builtins.str] create_time: The time when the certificate was created.
        :param pulumi.Input[builtins.str] csr: Certificate signing request content.
        :param pulumi.Input[builtins.str] pkey_type: The private key algorithm type.
        :param pulumi.Input[builtins.int] site_id: Site Id
        :param pulumi.Input[builtins.str] status: The certificate status. Valid values: `revoked`, `active`.
        :param pulumi.Input[builtins.str] validity_days: Certificate validity period.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ClientCertificateState.__new__(_ClientCertificateState)

        __props__.__dict__["client_cert_id"] = client_cert_id
        __props__.__dict__["create_time"] = create_time
        __props__.__dict__["csr"] = csr
        __props__.__dict__["pkey_type"] = pkey_type
        __props__.__dict__["site_id"] = site_id
        __props__.__dict__["status"] = status
        __props__.__dict__["validity_days"] = validity_days
        return ClientCertificate(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="clientCertId")
    def client_cert_id(self) -> pulumi.Output[builtins.str]:
        """
        ClientCertificate Id
        """
        return pulumi.get(self, "client_cert_id")

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> pulumi.Output[builtins.str]:
        """
        The time when the certificate was created.
        """
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter
    def csr(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Certificate signing request content.
        """
        return pulumi.get(self, "csr")

    @property
    @pulumi.getter(name="pkeyType")
    def pkey_type(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        The private key algorithm type.
        """
        return pulumi.get(self, "pkey_type")

    @property
    @pulumi.getter(name="siteId")
    def site_id(self) -> pulumi.Output[builtins.int]:
        """
        Site Id
        """
        return pulumi.get(self, "site_id")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[builtins.str]:
        """
        The certificate status. Valid values: `revoked`, `active`.
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="validityDays")
    def validity_days(self) -> pulumi.Output[builtins.str]:
        """
        Certificate validity period.
        """
        return pulumi.get(self, "validity_days")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['PolicyArgs', 'Policy']

@pulumi.input_type
class PolicyArgs:
    def __init__(__self__, *,
                 camera_redirect: Optional[pulumi.Input[builtins.str]] = None,
                 clipboard: Optional[pulumi.Input[builtins.str]] = None,
                 lock_resolution: Optional[pulumi.Input[builtins.str]] = None,
                 net_redirect_policy: Optional[pulumi.Input['PolicyNetRedirectPolicyArgs']] = None,
                 policy_group_name: Optional[pulumi.Input[builtins.str]] = None,
                 resolution_height: Optional[pulumi.Input[builtins.int]] = None,
                 resolution_width: Optional[pulumi.Input[builtins.int]] = None):
        """
        The set of arguments for constructing a Policy resource.
        :param pulumi.Input[builtins.str] camera_redirect: Whether to turn on local camera redirection.
        :param pulumi.Input[builtins.str] clipboard: Clipboard permissions.
        :param pulumi.Input[builtins.str] lock_resolution: Whether to lock the resolution.
        :param pulumi.Input['PolicyNetRedirectPolicyArgs'] net_redirect_policy: Network redirection. See `net_redirect_policy` below.
        :param pulumi.Input[builtins.str] policy_group_name: The policy name.
        :param pulumi.Input[builtins.int] resolution_height: The height of the resolution. Unit: Pixels.
        :param pulumi.Input[builtins.int] resolution_width: The width of the resolution. Unit: Pixels.
        """
        if camera_redirect is not None:
            pulumi.set(__self__, "camera_redirect", camera_redirect)
        if clipboard is not None:
            pulumi.set(__self__, "clipboard", clipboard)
        if lock_resolution is not None:
            pulumi.set(__self__, "lock_resolution", lock_resolution)
        if net_redirect_policy is not None:
            pulumi.set(__self__, "net_redirect_policy", net_redirect_policy)
        if policy_group_name is not None:
            pulumi.set(__self__, "policy_group_name", policy_group_name)
        if resolution_height is not None:
            pulumi.set(__self__, "resolution_height", resolution_height)
        if resolution_width is not None:
            pulumi.set(__self__, "resolution_width", resolution_width)

    @property
    @pulumi.getter(name="cameraRedirect")
    def camera_redirect(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Whether to turn on local camera redirection.
        """
        return pulumi.get(self, "camera_redirect")

    @camera_redirect.setter
    def camera_redirect(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "camera_redirect", value)

    @property
    @pulumi.getter
    def clipboard(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Clipboard permissions.
        """
        return pulumi.get(self, "clipboard")

    @clipboard.setter
    def clipboard(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "clipboard", value)

    @property
    @pulumi.getter(name="lockResolution")
    def lock_resolution(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Whether to lock the resolution.
        """
        return pulumi.get(self, "lock_resolution")

    @lock_resolution.setter
    def lock_resolution(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "lock_resolution", value)

    @property
    @pulumi.getter(name="netRedirectPolicy")
    def net_redirect_policy(self) -> Optional[pulumi.Input['PolicyNetRedirectPolicyArgs']]:
        """
        Network redirection. See `net_redirect_policy` below.
        """
        return pulumi.get(self, "net_redirect_policy")

    @net_redirect_policy.setter
    def net_redirect_policy(self, value: Optional[pulumi.Input['PolicyNetRedirectPolicyArgs']]):
        pulumi.set(self, "net_redirect_policy", value)

    @property
    @pulumi.getter(name="policyGroupName")
    def policy_group_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The policy name.
        """
        return pulumi.get(self, "policy_group_name")

    @policy_group_name.setter
    def policy_group_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "policy_group_name", value)

    @property
    @pulumi.getter(name="resolutionHeight")
    def resolution_height(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        The height of the resolution. Unit: Pixels.
        """
        return pulumi.get(self, "resolution_height")

    @resolution_height.setter
    def resolution_height(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "resolution_height", value)

    @property
    @pulumi.getter(name="resolutionWidth")
    def resolution_width(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        The width of the resolution. Unit: Pixels.
        """
        return pulumi.get(self, "resolution_width")

    @resolution_width.setter
    def resolution_width(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "resolution_width", value)


@pulumi.input_type
class _PolicyState:
    def __init__(__self__, *,
                 camera_redirect: Optional[pulumi.Input[builtins.str]] = None,
                 clipboard: Optional[pulumi.Input[builtins.str]] = None,
                 lock_resolution: Optional[pulumi.Input[builtins.str]] = None,
                 net_redirect_policy: Optional[pulumi.Input['PolicyNetRedirectPolicyArgs']] = None,
                 policy_group_name: Optional[pulumi.Input[builtins.str]] = None,
                 resolution_height: Optional[pulumi.Input[builtins.int]] = None,
                 resolution_width: Optional[pulumi.Input[builtins.int]] = None):
        """
        Input properties used for looking up and filtering Policy resources.
        :param pulumi.Input[builtins.str] camera_redirect: Whether to turn on local camera redirection.
        :param pulumi.Input[builtins.str] clipboard: Clipboard permissions.
        :param pulumi.Input[builtins.str] lock_resolution: Whether to lock the resolution.
        :param pulumi.Input['PolicyNetRedirectPolicyArgs'] net_redirect_policy: Network redirection. See `net_redirect_policy` below.
        :param pulumi.Input[builtins.str] policy_group_name: The policy name.
        :param pulumi.Input[builtins.int] resolution_height: The height of the resolution. Unit: Pixels.
        :param pulumi.Input[builtins.int] resolution_width: The width of the resolution. Unit: Pixels.
        """
        if camera_redirect is not None:
            pulumi.set(__self__, "camera_redirect", camera_redirect)
        if clipboard is not None:
            pulumi.set(__self__, "clipboard", clipboard)
        if lock_resolution is not None:
            pulumi.set(__self__, "lock_resolution", lock_resolution)
        if net_redirect_policy is not None:
            pulumi.set(__self__, "net_redirect_policy", net_redirect_policy)
        if policy_group_name is not None:
            pulumi.set(__self__, "policy_group_name", policy_group_name)
        if resolution_height is not None:
            pulumi.set(__self__, "resolution_height", resolution_height)
        if resolution_width is not None:
            pulumi.set(__self__, "resolution_width", resolution_width)

    @property
    @pulumi.getter(name="cameraRedirect")
    def camera_redirect(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Whether to turn on local camera redirection.
        """
        return pulumi.get(self, "camera_redirect")

    @camera_redirect.setter
    def camera_redirect(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "camera_redirect", value)

    @property
    @pulumi.getter
    def clipboard(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Clipboard permissions.
        """
        return pulumi.get(self, "clipboard")

    @clipboard.setter
    def clipboard(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "clipboard", value)

    @property
    @pulumi.getter(name="lockResolution")
    def lock_resolution(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Whether to lock the resolution.
        """
        return pulumi.get(self, "lock_resolution")

    @lock_resolution.setter
    def lock_resolution(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "lock_resolution", value)

    @property
    @pulumi.getter(name="netRedirectPolicy")
    def net_redirect_policy(self) -> Optional[pulumi.Input['PolicyNetRedirectPolicyArgs']]:
        """
        Network redirection. See `net_redirect_policy` below.
        """
        return pulumi.get(self, "net_redirect_policy")

    @net_redirect_policy.setter
    def net_redirect_policy(self, value: Optional[pulumi.Input['PolicyNetRedirectPolicyArgs']]):
        pulumi.set(self, "net_redirect_policy", value)

    @property
    @pulumi.getter(name="policyGroupName")
    def policy_group_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The policy name.
        """
        return pulumi.get(self, "policy_group_name")

    @policy_group_name.setter
    def policy_group_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "policy_group_name", value)

    @property
    @pulumi.getter(name="resolutionHeight")
    def resolution_height(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        The height of the resolution. Unit: Pixels.
        """
        return pulumi.get(self, "resolution_height")

    @resolution_height.setter
    def resolution_height(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "resolution_height", value)

    @property
    @pulumi.getter(name="resolutionWidth")
    def resolution_width(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        The width of the resolution. Unit: Pixels.
        """
        return pulumi.get(self, "resolution_width")

    @resolution_width.setter
    def resolution_width(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "resolution_width", value)


@pulumi.type_token("alicloud:cloudphone/policy:Policy")
class Policy(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 camera_redirect: Optional[pulumi.Input[builtins.str]] = None,
                 clipboard: Optional[pulumi.Input[builtins.str]] = None,
                 lock_resolution: Optional[pulumi.Input[builtins.str]] = None,
                 net_redirect_policy: Optional[pulumi.Input[Union['PolicyNetRedirectPolicyArgs', 'PolicyNetRedirectPolicyArgsDict']]] = None,
                 policy_group_name: Optional[pulumi.Input[builtins.str]] = None,
                 resolution_height: Optional[pulumi.Input[builtins.int]] = None,
                 resolution_width: Optional[pulumi.Input[builtins.int]] = None,
                 __props__=None):
        """
        Provides a Cloud Phone Policy resource.

        Cloud phone policy.

        For information about Cloud Phone Policy and how to use it, see [What is Policy](https://next.api.alibabacloud.com/document/eds-aic/2023-09-30/CreatePolicyGroup).

        > **NOTE:** Available since v1.243.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        default = alicloud.cloudphone.Policy("default",
            policy_group_name="NewPolicyName",
            resolution_width=720,
            lock_resolution="on",
            camera_redirect="on",
            resolution_height=1280,
            clipboard="read",
            net_redirect_policy={
                "net_redirect": "on",
                "custom_proxy": "on",
                "proxy_type": "socks5",
                "host_addr": "192.168.12.13",
                "port": "8888",
                "proxy_user_name": "user1",
                "proxy_password": "123456",
            })
        ```

        ## Import

        Cloud Phone Policy can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:cloudphone/policy:Policy example <id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] camera_redirect: Whether to turn on local camera redirection.
        :param pulumi.Input[builtins.str] clipboard: Clipboard permissions.
        :param pulumi.Input[builtins.str] lock_resolution: Whether to lock the resolution.
        :param pulumi.Input[Union['PolicyNetRedirectPolicyArgs', 'PolicyNetRedirectPolicyArgsDict']] net_redirect_policy: Network redirection. See `net_redirect_policy` below.
        :param pulumi.Input[builtins.str] policy_group_name: The policy name.
        :param pulumi.Input[builtins.int] resolution_height: The height of the resolution. Unit: Pixels.
        :param pulumi.Input[builtins.int] resolution_width: The width of the resolution. Unit: Pixels.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[PolicyArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a Cloud Phone Policy resource.

        Cloud phone policy.

        For information about Cloud Phone Policy and how to use it, see [What is Policy](https://next.api.alibabacloud.com/document/eds-aic/2023-09-30/CreatePolicyGroup).

        > **NOTE:** Available since v1.243.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        default = alicloud.cloudphone.Policy("default",
            policy_group_name="NewPolicyName",
            resolution_width=720,
            lock_resolution="on",
            camera_redirect="on",
            resolution_height=1280,
            clipboard="read",
            net_redirect_policy={
                "net_redirect": "on",
                "custom_proxy": "on",
                "proxy_type": "socks5",
                "host_addr": "192.168.12.13",
                "port": "8888",
                "proxy_user_name": "user1",
                "proxy_password": "123456",
            })
        ```

        ## Import

        Cloud Phone Policy can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:cloudphone/policy:Policy example <id>
        ```

        :param str resource_name: The name of the resource.
        :param PolicyArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(PolicyArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 camera_redirect: Optional[pulumi.Input[builtins.str]] = None,
                 clipboard: Optional[pulumi.Input[builtins.str]] = None,
                 lock_resolution: Optional[pulumi.Input[builtins.str]] = None,
                 net_redirect_policy: Optional[pulumi.Input[Union['PolicyNetRedirectPolicyArgs', 'PolicyNetRedirectPolicyArgsDict']]] = None,
                 policy_group_name: Optional[pulumi.Input[builtins.str]] = None,
                 resolution_height: Optional[pulumi.Input[builtins.int]] = None,
                 resolution_width: Optional[pulumi.Input[builtins.int]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = PolicyArgs.__new__(PolicyArgs)

            __props__.__dict__["camera_redirect"] = camera_redirect
            __props__.__dict__["clipboard"] = clipboard
            __props__.__dict__["lock_resolution"] = lock_resolution
            __props__.__dict__["net_redirect_policy"] = net_redirect_policy
            __props__.__dict__["policy_group_name"] = policy_group_name
            __props__.__dict__["resolution_height"] = resolution_height
            __props__.__dict__["resolution_width"] = resolution_width
        super(Policy, __self__).__init__(
            'alicloud:cloudphone/policy:Policy',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            camera_redirect: Optional[pulumi.Input[builtins.str]] = None,
            clipboard: Optional[pulumi.Input[builtins.str]] = None,
            lock_resolution: Optional[pulumi.Input[builtins.str]] = None,
            net_redirect_policy: Optional[pulumi.Input[Union['PolicyNetRedirectPolicyArgs', 'PolicyNetRedirectPolicyArgsDict']]] = None,
            policy_group_name: Optional[pulumi.Input[builtins.str]] = None,
            resolution_height: Optional[pulumi.Input[builtins.int]] = None,
            resolution_width: Optional[pulumi.Input[builtins.int]] = None) -> 'Policy':
        """
        Get an existing Policy resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] camera_redirect: Whether to turn on local camera redirection.
        :param pulumi.Input[builtins.str] clipboard: Clipboard permissions.
        :param pulumi.Input[builtins.str] lock_resolution: Whether to lock the resolution.
        :param pulumi.Input[Union['PolicyNetRedirectPolicyArgs', 'PolicyNetRedirectPolicyArgsDict']] net_redirect_policy: Network redirection. See `net_redirect_policy` below.
        :param pulumi.Input[builtins.str] policy_group_name: The policy name.
        :param pulumi.Input[builtins.int] resolution_height: The height of the resolution. Unit: Pixels.
        :param pulumi.Input[builtins.int] resolution_width: The width of the resolution. Unit: Pixels.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _PolicyState.__new__(_PolicyState)

        __props__.__dict__["camera_redirect"] = camera_redirect
        __props__.__dict__["clipboard"] = clipboard
        __props__.__dict__["lock_resolution"] = lock_resolution
        __props__.__dict__["net_redirect_policy"] = net_redirect_policy
        __props__.__dict__["policy_group_name"] = policy_group_name
        __props__.__dict__["resolution_height"] = resolution_height
        __props__.__dict__["resolution_width"] = resolution_width
        return Policy(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="cameraRedirect")
    def camera_redirect(self) -> pulumi.Output[builtins.str]:
        """
        Whether to turn on local camera redirection.
        """
        return pulumi.get(self, "camera_redirect")

    @property
    @pulumi.getter
    def clipboard(self) -> pulumi.Output[builtins.str]:
        """
        Clipboard permissions.
        """
        return pulumi.get(self, "clipboard")

    @property
    @pulumi.getter(name="lockResolution")
    def lock_resolution(self) -> pulumi.Output[builtins.str]:
        """
        Whether to lock the resolution.
        """
        return pulumi.get(self, "lock_resolution")

    @property
    @pulumi.getter(name="netRedirectPolicy")
    def net_redirect_policy(self) -> pulumi.Output['outputs.PolicyNetRedirectPolicy']:
        """
        Network redirection. See `net_redirect_policy` below.
        """
        return pulumi.get(self, "net_redirect_policy")

    @property
    @pulumi.getter(name="policyGroupName")
    def policy_group_name(self) -> pulumi.Output[builtins.str]:
        """
        The policy name.
        """
        return pulumi.get(self, "policy_group_name")

    @property
    @pulumi.getter(name="resolutionHeight")
    def resolution_height(self) -> pulumi.Output[builtins.int]:
        """
        The height of the resolution. Unit: Pixels.
        """
        return pulumi.get(self, "resolution_height")

    @property
    @pulumi.getter(name="resolutionWidth")
    def resolution_width(self) -> pulumi.Output[builtins.int]:
        """
        The width of the resolution. Unit: Pixels.
        """
        return pulumi.get(self, "resolution_width")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['ClientCaCertificateArgs', 'ClientCaCertificate']

@pulumi.input_type
class ClientCaCertificateArgs:
    def __init__(__self__, *,
                 certificate: pulumi.Input[builtins.str],
                 site_id: pulumi.Input[builtins.int],
                 client_ca_cert_name: Optional[pulumi.Input[builtins.str]] = None):
        """
        The set of arguments for constructing a ClientCaCertificate resource.
        :param pulumi.Input[builtins.str] certificate: Certificate content.
        :param pulumi.Input[builtins.int] site_id: Site Id
        :param pulumi.Input[builtins.str] client_ca_cert_name: The certificate name.
        """
        pulumi.set(__self__, "certificate", certificate)
        pulumi.set(__self__, "site_id", site_id)
        if client_ca_cert_name is not None:
            pulumi.set(__self__, "client_ca_cert_name", client_ca_cert_name)

    @property
    @pulumi.getter
    def certificate(self) -> pulumi.Input[builtins.str]:
        """
        Certificate content.
        """
        return pulumi.get(self, "certificate")

    @certificate.setter
    def certificate(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "certificate", value)

    @property
    @pulumi.getter(name="siteId")
    def site_id(self) -> pulumi.Input[builtins.int]:
        """
        Site Id
        """
        return pulumi.get(self, "site_id")

    @site_id.setter
    def site_id(self, value: pulumi.Input[builtins.int]):
        pulumi.set(self, "site_id", value)

    @property
    @pulumi.getter(name="clientCaCertName")
    def client_ca_cert_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The certificate name.
        """
        return pulumi.get(self, "client_ca_cert_name")

    @client_ca_cert_name.setter
    def client_ca_cert_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "client_ca_cert_name", value)


@pulumi.input_type
class _ClientCaCertificateState:
    def __init__(__self__, *,
                 certificate: Optional[pulumi.Input[builtins.str]] = None,
                 client_ca_cert_id: Optional[pulumi.Input[builtins.str]] = None,
                 client_ca_cert_name: Optional[pulumi.Input[builtins.str]] = None,
                 create_time: Optional[pulumi.Input[builtins.str]] = None,
                 site_id: Optional[pulumi.Input[builtins.int]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering ClientCaCertificate resources.
        :param pulumi.Input[builtins.str] certificate: Certificate content.
        :param pulumi.Input[builtins.str] client_ca_cert_id: ClientCaCertificate Id
        :param pulumi.Input[builtins.str] client_ca_cert_name: The certificate name.
        :param pulumi.Input[builtins.str] create_time: Creation time.
        :param pulumi.Input[builtins.int] site_id: Site Id
        :param pulumi.Input[builtins.str] status: Certificate status.
        """
        if certificate is not None:
            pulumi.set(__self__, "certificate", certificate)
        if client_ca_cert_id is not None:
            pulumi.set(__self__, "client_ca_cert_id", client_ca_cert_id)
        if client_ca_cert_name is not None:
            pulumi.set(__self__, "client_ca_cert_name", client_ca_cert_name)
        if create_time is not None:
            pulumi.set(__self__, "create_time", create_time)
        if site_id is not None:
            pulumi.set(__self__, "site_id", site_id)
        if status is not None:
            pulumi.set(__self__, "status", status)

    @property
    @pulumi.getter
    def certificate(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Certificate content.
        """
        return pulumi.get(self, "certificate")

    @certificate.setter
    def certificate(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "certificate", value)

    @property
    @pulumi.getter(name="clientCaCertId")
    def client_ca_cert_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        ClientCaCertificate Id
        """
        return pulumi.get(self, "client_ca_cert_id")

    @client_ca_cert_id.setter
    def client_ca_cert_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "client_ca_cert_id", value)

    @property
    @pulumi.getter(name="clientCaCertName")
    def client_ca_cert_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The certificate name.
        """
        return pulumi.get(self, "client_ca_cert_name")

    @client_ca_cert_name.setter
    def client_ca_cert_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "client_ca_cert_name", value)

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Creation time.
        """
        return pulumi.get(self, "create_time")

    @create_time.setter
    def create_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "create_time", value)

    @property
    @pulumi.getter(name="siteId")
    def site_id(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        Site Id
        """
        return pulumi.get(self, "site_id")

    @site_id.setter
    def site_id(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "site_id", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Certificate status.
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "status", value)


@pulumi.type_token("alicloud:esa/clientCaCertificate:ClientCaCertificate")
class ClientCaCertificate(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 certificate: Optional[pulumi.Input[builtins.str]] = None,
                 client_ca_cert_name: Optional[pulumi.Input[builtins.str]] = None,
                 site_id: Optional[pulumi.Input[builtins.int]] = None,
                 __props__=None):
        """
        Provides a ESA Client Ca Certificate resource.

        For information about ESA Client Ca Certificate and how to use it, see [What is Client Ca Certificate](https://next.api.alibabacloud.com/document/ESA/2024-09-10/UploadClientCaCertificate).

        > **NOTE:** Available since v1.244.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        default = alicloud.esa.get_sites(plan_subscribe_type="enterpriseplan",
            site_name="gositecdn.cn")
        default_client_ca_certificate = alicloud.esa.ClientCaCertificate("default",
            certificate=\"\"\"-----BEGIN CERTIFICATE-----
        ****-----END CERTIFICATE-----\"\"\",
            client_ca_cert_name="example",
            site_id=default.sites[0].id)
        ```

        ## Import

        ESA Client Ca Certificate can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:esa/clientCaCertificate:ClientCaCertificate example <site_id>:<client_ca_cert_id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] certificate: Certificate content.
        :param pulumi.Input[builtins.str] client_ca_cert_name: The certificate name.
        :param pulumi.Input[builtins.int] site_id: Site Id
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ClientCaCertificateArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a ESA Client Ca Certificate resource.

        For information about ESA Client Ca Certificate and how to use it, see [What is Client Ca Certificate](https://next.api.alibabacloud.com/document/ESA/2024-09-10/UploadClientCaCertificate).

        > **NOTE:** Available since v1.244.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        default = alicloud.esa.get_sites(plan_subscribe_type="enterpriseplan",
            site_name="gositecdn.cn")
        default_client_ca_certificate = alicloud.esa.ClientCaCertificate("default",
            certificate=\"\"\"-----BEGIN CERTIFICATE-----
        ****-----END CERTIFICATE-----\"\"\",
            client_ca_cert_name="example",
            site_id=default.sites[0].id)
        ```

        ## Import

        ESA Client Ca Certificate can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:esa/clientCaCertificate:ClientCaCertificate example <site_id>:<client_ca_cert_id>
        ```

        :param str resource_name: The name of the resource.
        :param ClientCaCertificateArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ClientCaCertificateArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 certificate: Optional[pulumi.Input[builtins.str]] = None,
                 client_ca_cert_name: Optional[pulumi.Input[builtins.str]] = None,
                 site_id: Optional[pulumi.Input[builtins.int]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ClientCaCertificateArgs.__new__(ClientCaCertificateArgs)

            if certificate is None and not opts.urn:
                raise TypeError("Missing required property 'certificate'")
            __props__.__dict__["certificate"] = certificate
            __props__.__dict__["client_ca_cert_name"] = client_ca_cert_name
            if site_id is None and not opts.urn:
                raise TypeError("Missing required property 'site_id'")
            __props__.__dict__["site_id"] = site_id
            __props__.__dict__["client_ca_cert_id"] = None
            __props__.__dict__["create_time"] = None
            __props__.__dict__["status"] = None
        super(ClientCaCertificate, __self__).__init__(
            'alicloud:esa/clientCaCertificate:ClientCaCertificate',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            certificate: Optional[pulumi.Input[builtins.str]] = None,
            client_ca_cert_id: Optional[pulumi.Input[builtins.str]] = None,
            client_ca_cert_name: Optional[pulumi.Input[builtins.str]] = None,
            create_time: Optional[pulumi.Input[builtins.str]] = None,
            site_id: Optional[pulumi.Input[builtins.int]] = None,
            status: Optional[pulumi.Input[builtins.str]] = None) -> 'ClientCaCertificate':
        """
        Get an existing ClientCaCertificate resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] certificate: Certificate content.
        :param pulumi.Input[builtins.str] client_ca_cert_id: ClientCaCertificate Id
        :param pulumi.Input[builtins.str] client_ca_cert_name: The certificate name.
        :param pulumi.Input[builtins.str] create_time: Creation time.
        :param pulumi.Input[builtins.int] site_id: Site Id
        :param pulumi.Input[builtins.str] status: Certificate status.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ClientCaCertificateState.__new__(_ClientCaCertificateState)

        __props__.__dict__["certificate"] = certificate
        __props__.__dict__["client_ca_cert_id"] = client_ca_cert_id
        __props__.__dict__["client_ca_cert_name"] = client_ca_cert_name
        __props__.__dict__["create_time"] = create_time
        __props__.__dict__["site_id"] = site_id
        __props__.__dict__["status"] = status
        return ClientCaCertificate(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def certificate(self) -> pulumi.Output[builtins.str]:
        """
        Certificate content.
        """
        return pulumi.get(self, "certificate")

    @property
    @pulumi.getter(name="clientCaCertId")
    def client_ca_cert_id(self) -> pulumi.Output[builtins.str]:
        """
        ClientCaCertificate Id
        """
        return pulumi.get(self, "client_ca_cert_id")

    @property
    @pulumi.getter(name="clientCaCertName")
    def client_ca_cert_name(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        The certificate name.
        """
        return pulumi.get(self, "client_ca_cert_name")

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> pulumi.Output[builtins.str]:
        """
        Creation time.
        """
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter(name="siteId")
    def site_id(self) -> pulumi.Output[builtins.int]:
        """
        Site Id
        """
        return pulumi.get(self, "site_id")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[builtins.str]:
        """
        Certificate status.
        """
        return pulumi.get(self, "status")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['EdgeContainerAppRecordArgs', 'EdgeContainerAppRecord']

@pulumi.input_type
class EdgeContainerAppRecordArgs:
    def __init__(__self__, *,
                 app_id: pulumi.Input[builtins.str],
                 record_name: pulumi.Input[builtins.str],
                 site_id: Optional[pulumi.Input[builtins.int]] = None):
        """
        The set of arguments for constructing a EdgeContainerAppRecord resource.
        :param pulumi.Input[builtins.str] app_id: The application ID
        :param pulumi.Input[builtins.str] record_name: The associated domain name.
        :param pulumi.Input[builtins.int] site_id: The website ID.
        """
        pulumi.set(__self__, "app_id", app_id)
        pulumi.set(__self__, "record_name", record_name)
        if site_id is not None:
            pulumi.set(__self__, "site_id", site_id)

    @property
    @pulumi.getter(name="appId")
    def app_id(self) -> pulumi.Input[builtins.str]:
        """
        The application ID
        """
        return pulumi.get(self, "app_id")

    @app_id.setter
    def app_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "app_id", value)

    @property
    @pulumi.getter(name="recordName")
    def record_name(self) -> pulumi.Input[builtins.str]:
        """
        The associated domain name.
        """
        return pulumi.get(self, "record_name")

    @record_name.setter
    def record_name(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "record_name", value)

    @property
    @pulumi.getter(name="siteId")
    def site_id(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        The website ID.
        """
        return pulumi.get(self, "site_id")

    @site_id.setter
    def site_id(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "site_id", value)


@pulumi.input_type
class _EdgeContainerAppRecordState:
    def __init__(__self__, *,
                 app_id: Optional[pulumi.Input[builtins.str]] = None,
                 create_time: Optional[pulumi.Input[builtins.str]] = None,
                 record_name: Optional[pulumi.Input[builtins.str]] = None,
                 site_id: Optional[pulumi.Input[builtins.int]] = None):
        """
        Input properties used for looking up and filtering EdgeContainerAppRecord resources.
        :param pulumi.Input[builtins.str] app_id: The application ID
        :param pulumi.Input[builtins.str] create_time: The time when the domain name was added. The time follows the ISO 8601 standard in the YYYY-MM-DDThh:mm:ss format. The time is displayed in UTC.
        :param pulumi.Input[builtins.str] record_name: The associated domain name.
        :param pulumi.Input[builtins.int] site_id: The website ID.
        """
        if app_id is not None:
            pulumi.set(__self__, "app_id", app_id)
        if create_time is not None:
            pulumi.set(__self__, "create_time", create_time)
        if record_name is not None:
            pulumi.set(__self__, "record_name", record_name)
        if site_id is not None:
            pulumi.set(__self__, "site_id", site_id)

    @property
    @pulumi.getter(name="appId")
    def app_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The application ID
        """
        return pulumi.get(self, "app_id")

    @app_id.setter
    def app_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "app_id", value)

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The time when the domain name was added. The time follows the ISO 8601 standard in the YYYY-MM-DDThh:mm:ss format. The time is displayed in UTC.
        """
        return pulumi.get(self, "create_time")

    @create_time.setter
    def create_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "create_time", value)

    @property
    @pulumi.getter(name="recordName")
    def record_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The associated domain name.
        """
        return pulumi.get(self, "record_name")

    @record_name.setter
    def record_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "record_name", value)

    @property
    @pulumi.getter(name="siteId")
    def site_id(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        The website ID.
        """
        return pulumi.get(self, "site_id")

    @site_id.setter
    def site_id(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "site_id", value)


@pulumi.type_token("alicloud:esa/edgeContainerAppRecord:EdgeContainerAppRecord")
class EdgeContainerAppRecord(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 app_id: Optional[pulumi.Input[builtins.str]] = None,
                 record_name: Optional[pulumi.Input[builtins.str]] = None,
                 site_id: Optional[pulumi.Input[builtins.int]] = None,
                 __props__=None):
        """
        Provides a ESA Edge Container App Record resource.

        For information about ESA Edge Container App Record and how to use it, see [What is Edge Container App Record](https://next.api.alibabacloud.com/document/ESA/2024-09-10/CreateEdgeContainerAppRecord).

        > **NOTE:** Available since v1.247.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud
        import pulumi_random as random

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform.com"
        default = alicloud.esa.get_sites(plan_subscribe_type="enterpriseplan")
        default_integer = random.index.Integer("default",
            min=10000,
            max=99999)
        resource_site_origin_pool_test = alicloud.esa.Site("resource_Site_OriginPool_test",
            site_name=f"gositecdn-{default_integer['result']}.cn",
            instance_id=default.sites[0].instance_id,
            coverage="overseas",
            access_type="NS")
        default_edge_container_app = alicloud.esa.EdgeContainerApp("default",
            health_check_host="example.com",
            health_check_type="l7",
            service_port=80,
            health_check_interval=5,
            edge_container_app_name="terraform-app",
            health_check_http_code="http_2xx",
            health_check_uri="/",
            health_check_timeout=3,
            health_check_succ_times=2,
            remarks=name,
            health_check_method="HEAD",
            health_check_port=80,
            health_check_fail_times=5,
            target_port=3000)
        default_edge_container_app_record = alicloud.esa.EdgeContainerAppRecord("default",
            record_name="tf.terraform.com",
            site_id=resource_site_origin_pool_test.id,
            app_id=default_edge_container_app.id)
        ```

        ## Import

        ESA Edge Container App Record can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:esa/edgeContainerAppRecord:EdgeContainerAppRecord example <site_id>:<app_id>:<record_name>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] app_id: The application ID
        :param pulumi.Input[builtins.str] record_name: The associated domain name.
        :param pulumi.Input[builtins.int] site_id: The website ID.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: EdgeContainerAppRecordArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a ESA Edge Container App Record resource.

        For information about ESA Edge Container App Record and how to use it, see [What is Edge Container App Record](https://next.api.alibabacloud.com/document/ESA/2024-09-10/CreateEdgeContainerAppRecord).

        > **NOTE:** Available since v1.247.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud
        import pulumi_random as random

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform.com"
        default = alicloud.esa.get_sites(plan_subscribe_type="enterpriseplan")
        default_integer = random.index.Integer("default",
            min=10000,
            max=99999)
        resource_site_origin_pool_test = alicloud.esa.Site("resource_Site_OriginPool_test",
            site_name=f"gositecdn-{default_integer['result']}.cn",
            instance_id=default.sites[0].instance_id,
            coverage="overseas",
            access_type="NS")
        default_edge_container_app = alicloud.esa.EdgeContainerApp("default",
            health_check_host="example.com",
            health_check_type="l7",
            service_port=80,
            health_check_interval=5,
            edge_container_app_name="terraform-app",
            health_check_http_code="http_2xx",
            health_check_uri="/",
            health_check_timeout=3,
            health_check_succ_times=2,
            remarks=name,
            health_check_method="HEAD",
            health_check_port=80,
            health_check_fail_times=5,
            target_port=3000)
        default_edge_container_app_record = alicloud.esa.EdgeContainerAppRecord("default",
            record_name="tf.terraform.com",
            site_id=resource_site_origin_pool_test.id,
            app_id=default_edge_container_app.id)
        ```

        ## Import

        ESA Edge Container App Record can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:esa/edgeContainerAppRecord:EdgeContainerAppRecord example <site_id>:<app_id>:<record_name>
        ```

        :param str resource_name: The name of the resource.
        :param EdgeContainerAppRecordArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(EdgeContainerAppRecordArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 app_id: Optional[pulumi.Input[builtins.str]] = None,
                 record_name: Optional[pulumi.Input[builtins.str]] = None,
                 site_id: Optional[pulumi.Input[builtins.int]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = EdgeContainerAppRecordArgs.__new__(EdgeContainerAppRecordArgs)

            if app_id is None and not opts.urn:
                raise TypeError("Missing required property 'app_id'")
            __props__.__dict__["app_id"] = app_id
            if record_name is None and not opts.urn:
                raise TypeError("Missing required property 'record_name'")
            __props__.__dict__["record_name"] = record_name
            __props__.__dict__["site_id"] = site_id
            __props__.__dict__["create_time"] = None
        super(EdgeContainerAppRecord, __self__).__init__(
            'alicloud:esa/edgeContainerAppRecord:EdgeContainerAppRecord',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            app_id: Optional[pulumi.Input[builtins.str]] = None,
            create_time: Optional[pulumi.Input[builtins.str]] = None,
            record_name: Optional[pulumi.Input[builtins.str]] = None,
            site_id: Optional[pulumi.Input[builtins.int]] = None) -> 'EdgeContainerAppRecord':
        """
        Get an existing EdgeContainerAppRecord resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] app_id: The application ID
        :param pulumi.Input[builtins.str] create_time: The time when the domain name was added. The time follows the ISO 8601 standard in the YYYY-MM-DDThh:mm:ss format. The time is displayed in UTC.
        :param pulumi.Input[builtins.str] record_name: The associated domain name.
        :param pulumi.Input[builtins.int] site_id: The website ID.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _EdgeContainerAppRecordState.__new__(_EdgeContainerAppRecordState)

        __props__.__dict__["app_id"] = app_id
        __props__.__dict__["create_time"] = create_time
        __props__.__dict__["record_name"] = record_name
        __props__.__dict__["site_id"] = site_id
        return EdgeContainerAppRecord(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="appId")
    def app_id(self) -> pulumi.Output[builtins.str]:
        """
        The application ID
        """
        return pulumi.get(self, "app_id")

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> pulumi.Output[builtins.str]:
        """
        The time when the domain name was added. The time follows the ISO 8601 standard in the YYYY-MM-DDThh:mm:ss format. The time is displayed in UTC.
        """
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter(name="recordName")
    def record_name(self) -> pulumi.Output[builtins.str]:
        """
        The associated domain name.
        """
        return pulumi.get(self, "record_name")

    @property
    @pulumi.getter(name="siteId")
    def site_id(self) -> pulumi.Output[builtins.int]:
        """
        The website ID.
        """
        return pulumi.get(self, "site_id")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['WaitingRoomRuleArgs', 'WaitingRoomRule']

@pulumi.input_type
class WaitingRoomRuleArgs:
    def __init__(__self__, *,
                 rule: pulumi.Input[builtins.str],
                 rule_name: pulumi.Input[builtins.str],
                 site_id: pulumi.Input[builtins.int],
                 status: pulumi.Input[builtins.str],
                 waiting_room_id: pulumi.Input[builtins.str]):
        """
        The set of arguments for constructing a WaitingRoomRule resource.
        :param pulumi.Input[builtins.str] rule: The content of the rule, the implemented policy or conditional expression.
        :param pulumi.Input[builtins.str] rule_name: Rule name, optional, used to query by waiting room bypass rule name.
        :param pulumi.Input[builtins.int] site_id: The site ID, which can be obtained by calling the ListSites API.
        :param pulumi.Input[builtins.str] status: Rule enabled status, supporting:
               -'on': means enabled.
               -'off': means disabled.
        :param pulumi.Input[builtins.str] waiting_room_id: Waiting room ID, used to identify a specific waiting room. It can be obtained by calling the [listwaitingroom](https://help.aliyun.com/document_detail/2850279.html) interface.
        """
        pulumi.set(__self__, "rule", rule)
        pulumi.set(__self__, "rule_name", rule_name)
        pulumi.set(__self__, "site_id", site_id)
        pulumi.set(__self__, "status", status)
        pulumi.set(__self__, "waiting_room_id", waiting_room_id)

    @property
    @pulumi.getter
    def rule(self) -> pulumi.Input[builtins.str]:
        """
        The content of the rule, the implemented policy or conditional expression.
        """
        return pulumi.get(self, "rule")

    @rule.setter
    def rule(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "rule", value)

    @property
    @pulumi.getter(name="ruleName")
    def rule_name(self) -> pulumi.Input[builtins.str]:
        """
        Rule name, optional, used to query by waiting room bypass rule name.
        """
        return pulumi.get(self, "rule_name")

    @rule_name.setter
    def rule_name(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "rule_name", value)

    @property
    @pulumi.getter(name="siteId")
    def site_id(self) -> pulumi.Input[builtins.int]:
        """
        The site ID, which can be obtained by calling the ListSites API.
        """
        return pulumi.get(self, "site_id")

    @site_id.setter
    def site_id(self, value: pulumi.Input[builtins.int]):
        pulumi.set(self, "site_id", value)

    @property
    @pulumi.getter
    def status(self) -> pulumi.Input[builtins.str]:
        """
        Rule enabled status, supporting:
        -'on': means enabled.
        -'off': means disabled.
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter(name="waitingRoomId")
    def waiting_room_id(self) -> pulumi.Input[builtins.str]:
        """
        Waiting room ID, used to identify a specific waiting room. It can be obtained by calling the [listwaitingroom](https://help.aliyun.com/document_detail/2850279.html) interface.
        """
        return pulumi.get(self, "waiting_room_id")

    @waiting_room_id.setter
    def waiting_room_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "waiting_room_id", value)


@pulumi.input_type
class _WaitingRoomRuleState:
    def __init__(__self__, *,
                 rule: Optional[pulumi.Input[builtins.str]] = None,
                 rule_name: Optional[pulumi.Input[builtins.str]] = None,
                 site_id: Optional[pulumi.Input[builtins.int]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None,
                 waiting_room_id: Optional[pulumi.Input[builtins.str]] = None,
                 waiting_room_rule_id: Optional[pulumi.Input[builtins.int]] = None):
        """
        Input properties used for looking up and filtering WaitingRoomRule resources.
        :param pulumi.Input[builtins.str] rule: The content of the rule, the implemented policy or conditional expression.
        :param pulumi.Input[builtins.str] rule_name: Rule name, optional, used to query by waiting room bypass rule name.
        :param pulumi.Input[builtins.int] site_id: The site ID, which can be obtained by calling the ListSites API.
        :param pulumi.Input[builtins.str] status: Rule enabled status, supporting:
               -'on': means enabled.
               -'off': means disabled.
        :param pulumi.Input[builtins.str] waiting_room_id: Waiting room ID, used to identify a specific waiting room. It can be obtained by calling the [listwaitingroom](https://help.aliyun.com/document_detail/2850279.html) interface.
        :param pulumi.Input[builtins.int] waiting_room_rule_id: The rule ID, which can be used to query a specific rule.
        """
        if rule is not None:
            pulumi.set(__self__, "rule", rule)
        if rule_name is not None:
            pulumi.set(__self__, "rule_name", rule_name)
        if site_id is not None:
            pulumi.set(__self__, "site_id", site_id)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if waiting_room_id is not None:
            pulumi.set(__self__, "waiting_room_id", waiting_room_id)
        if waiting_room_rule_id is not None:
            pulumi.set(__self__, "waiting_room_rule_id", waiting_room_rule_id)

    @property
    @pulumi.getter
    def rule(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The content of the rule, the implemented policy or conditional expression.
        """
        return pulumi.get(self, "rule")

    @rule.setter
    def rule(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "rule", value)

    @property
    @pulumi.getter(name="ruleName")
    def rule_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Rule name, optional, used to query by waiting room bypass rule name.
        """
        return pulumi.get(self, "rule_name")

    @rule_name.setter
    def rule_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "rule_name", value)

    @property
    @pulumi.getter(name="siteId")
    def site_id(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        The site ID, which can be obtained by calling the ListSites API.
        """
        return pulumi.get(self, "site_id")

    @site_id.setter
    def site_id(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "site_id", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Rule enabled status, supporting:
        -'on': means enabled.
        -'off': means disabled.
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter(name="waitingRoomId")
    def waiting_room_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Waiting room ID, used to identify a specific waiting room. It can be obtained by calling the [listwaitingroom](https://help.aliyun.com/document_detail/2850279.html) interface.
        """
        return pulumi.get(self, "waiting_room_id")

    @waiting_room_id.setter
    def waiting_room_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "waiting_room_id", value)

    @property
    @pulumi.getter(name="waitingRoomRuleId")
    def waiting_room_rule_id(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        The rule ID, which can be used to query a specific rule.
        """
        return pulumi.get(self, "waiting_room_rule_id")

    @waiting_room_rule_id.setter
    def waiting_room_rule_id(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "waiting_room_rule_id", value)


@pulumi.type_token("alicloud:esa/waitingRoomRule:WaitingRoomRule")
class WaitingRoomRule(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 rule: Optional[pulumi.Input[builtins.str]] = None,
                 rule_name: Optional[pulumi.Input[builtins.str]] = None,
                 site_id: Optional[pulumi.Input[builtins.int]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None,
                 waiting_room_id: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        Provides a ESA Waiting Room Rule resource.

        For information about ESA Waiting Room Rule and how to use it, see [What is Waiting Room Rule](https://next.api.alibabacloud.com/document/ESA/2024-09-10/CreateWaitingRoomRule).

        > **NOTE:** Available since v1.244.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        default = alicloud.esa.get_sites(plan_subscribe_type="enterpriseplan")
        default_site = alicloud.esa.Site("default",
            site_name="terraform.site",
            instance_id=default.sites[0].instance_id,
            coverage="overseas",
            access_type="NS")
        default_waiting_room = alicloud.esa.WaitingRoom("default",
            status="off",
            site_id=default_site.id,
            json_response_enable="off",
            description="example",
            waiting_room_type="default",
            disable_session_renewal_enable="off",
            cookie_name="__aliwaitingroom_example",
            waiting_room_name="waitingroom_example",
            queue_all_enable="off",
            queuing_status_code="200",
            custom_page_html="",
            new_users_per_minute="200",
            session_duration="5",
            language="zhcn",
            total_active_users="300",
            queuing_method="fifo",
            host_name_and_paths=[{
                "domain": "sub_domain.com",
                "path": "/example",
                "subdomain": "example_sub_domain.com.",
            }])
        default_waiting_room_rule = alicloud.esa.WaitingRoomRule("default",
            rule="(http.host eq \\"video.example.com\\")",
            waiting_room_id=default_waiting_room.waiting_room_id,
            rule_name="WaitingRoomRule_example1",
            status="off",
            site_id=default_site.id)
        ```

        ## Import

        ESA Waiting Room Rule can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:esa/waitingRoomRule:WaitingRoomRule example <site_id>:<waiting_room_id>:<waiting_room_rule_id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] rule: The content of the rule, the implemented policy or conditional expression.
        :param pulumi.Input[builtins.str] rule_name: Rule name, optional, used to query by waiting room bypass rule name.
        :param pulumi.Input[builtins.int] site_id: The site ID, which can be obtained by calling the ListSites API.
        :param pulumi.Input[builtins.str] status: Rule enabled status, supporting:
               -'on': means enabled.
               -'off': means disabled.
        :param pulumi.Input[builtins.str] waiting_room_id: Waiting room ID, used to identify a specific waiting room. It can be obtained by calling the [listwaitingroom](https://help.aliyun.com/document_detail/2850279.html) interface.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: WaitingRoomRuleArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a ESA Waiting Room Rule resource.

        For information about ESA Waiting Room Rule and how to use it, see [What is Waiting Room Rule](https://next.api.alibabacloud.com/document/ESA/2024-09-10/CreateWaitingRoomRule).

        > **NOTE:** Available since v1.244.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        default = alicloud.esa.get_sites(plan_subscribe_type="enterpriseplan")
        default_site = alicloud.esa.Site("default",
            site_name="terraform.site",
            instance_id=default.sites[0].instance_id,
            coverage="overseas",
            access_type="NS")
        default_waiting_room = alicloud.esa.WaitingRoom("default",
            status="off",
            site_id=default_site.id,
            json_response_enable="off",
            description="example",
            waiting_room_type="default",
            disable_session_renewal_enable="off",
            cookie_name="__aliwaitingroom_example",
            waiting_room_name="waitingroom_example",
            queue_all_enable="off",
            queuing_status_code="200",
            custom_page_html="",
            new_users_per_minute="200",
            session_duration="5",
            language="zhcn",
            total_active_users="300",
            queuing_method="fifo",
            host_name_and_paths=[{
                "domain": "sub_domain.com",
                "path": "/example",
                "subdomain": "example_sub_domain.com.",
            }])
        default_waiting_room_rule = alicloud.esa.WaitingRoomRule("default",
            rule="(http.host eq \\"video.example.com\\")",
            waiting_room_id=default_waiting_room.waiting_room_id,
            rule_name="WaitingRoomRule_example1",
            status="off",
            site_id=default_site.id)
        ```

        ## Import

        ESA Waiting Room Rule can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:esa/waitingRoomRule:WaitingRoomRule example <site_id>:<waiting_room_id>:<waiting_room_rule_id>
        ```

        :param str resource_name: The name of the resource.
        :param WaitingRoomRuleArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(WaitingRoomRuleArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 rule: Optional[pulumi.Input[builtins.str]] = None,
                 rule_name: Optional[pulumi.Input[builtins.str]] = None,
                 site_id: Optional[pulumi.Input[builtins.int]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None,
                 waiting_room_id: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = WaitingRoomRuleArgs.__new__(WaitingRoomRuleArgs)

            if rule is None and not opts.urn:
                raise TypeError("Missing required property 'rule'")
            __props__.__dict__["rule"] = rule
            if rule_name is None and not opts.urn:
                raise TypeError("Missing required property 'rule_name'")
            __props__.__dict__["rule_name"] = rule_name
            if site_id is None and not opts.urn:
                raise TypeError("Missing required property 'site_id'")
            __props__.__dict__["site_id"] = site_id
            if status is None and not opts.urn:
                raise TypeError("Missing required property 'status'")
            __props__.__dict__["status"] = status
            if waiting_room_id is None and not opts.urn:
                raise TypeError("Missing required property 'waiting_room_id'")
            __props__.__dict__["waiting_room_id"] = waiting_room_id
            __props__.__dict__["waiting_room_rule_id"] = None
        super(WaitingRoomRule, __self__).__init__(
            'alicloud:esa/waitingRoomRule:WaitingRoomRule',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            rule: Optional[pulumi.Input[builtins.str]] = None,
            rule_name: Optional[pulumi.Input[builtins.str]] = None,
            site_id: Optional[pulumi.Input[builtins.int]] = None,
            status: Optional[pulumi.Input[builtins.str]] = None,
            waiting_room_id: Optional[pulumi.Input[builtins.str]] = None,
            waiting_room_rule_id: Optional[pulumi.Input[builtins.int]] = None) -> 'WaitingRoomRule':
        """
        Get an existing WaitingRoomRule resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] rule: The content of the rule, the implemented policy or conditional expression.
        :param pulumi.Input[builtins.str] rule_name: Rule name, optional, used to query by waiting room bypass rule name.
        :param pulumi.Input[builtins.int] site_id: The site ID, which can be obtained by calling the ListSites API.
        :param pulumi.Input[builtins.str] status: Rule enabled status, supporting:
               -'on': means enabled.
               -'off': means disabled.
        :param pulumi.Input[builtins.str] waiting_room_id: Waiting room ID, used to identify a specific waiting room. It can be obtained by calling the [listwaitingroom](https://help.aliyun.com/document_detail/2850279.html) interface.
        :param pulumi.Input[builtins.int] waiting_room_rule_id: The rule ID, which can be used to query a specific rule.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _WaitingRoomRuleState.__new__(_WaitingRoomRuleState)

        __props__.__dict__["rule"] = rule
        __props__.__dict__["rule_name"] = rule_name
        __props__.__dict__["site_id"] = site_id
        __props__.__dict__["status"] = status
        __props__.__dict__["waiting_room_id"] = waiting_room_id
        __props__.__dict__["waiting_room_rule_id"] = waiting_room_rule_id
        return WaitingRoomRule(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def rule(self) -> pulumi.Output[builtins.str]:
        """
        The content of the rule, the implemented policy or conditional expression.
        """
        return pulumi.get(self, "rule")

    @property
    @pulumi.getter(name="ruleName")
    def rule_name(self) -> pulumi.Output[builtins.str]:
        """
        Rule name, optional, used to query by waiting room bypass rule name.
        """
        return pulumi.get(self, "rule_name")

    @property
    @pulumi.getter(name="siteId")
    def site_id(self) -> pulumi.Output[builtins.int]:
        """
        The site ID, which can be obtained by calling the ListSites API.
        """
        return pulumi.get(self, "site_id")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[builtins.str]:
        """
        Rule enabled status, supporting:
        -'on': means enabled.
        -'off': means disabled.
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="waitingRoomId")
    def waiting_room_id(self) -> pulumi.Output[builtins.str]:
        """
        Waiting room ID, used to identify a specific waiting room. It can be obtained by calling the [listwaitingroom](https://help.aliyun.com/document_detail/2850279.html) interface.
        """
        return pulumi.get(self, "waiting_room_id")

    @property
    @pulumi.getter(name="waitingRoomRuleId")
    def waiting_room_rule_id(self) -> pulumi.Output[builtins.int]:
        """
        The rule ID, which can be used to query a specific rule.
        """
        return pulumi.get(self, "waiting_room_rule_id")

